@@ -626,7 +626,7 @@ class FXDirectiveTests(unittest.TestCase):
                :loop: 1
 
             """)
-        for suffix in ("mp3", "ogg", "wav"):
+        for suffix in ("mp3", ".oga", "ogg", "wav"):
             with self.subTest(suffix=suffix):
                 text = content.format(suffix)
                 script = SceneScript("inline", doc=SceneScript.read(text))
@@ -655,6 +655,7 @@ class FXDirectiveTests(unittest.TestCase):
                :offset: 0
                :duration: 3000
                :loop: 1
+               :width: 480
 
             """)
         for suffix in ("jpg", "jpeg", "png"):
@@ -672,6 +673,46 @@ class FXDirectiveTests(unittest.TestCase):
                 self.assertEqual(0, cue.offset)
                 self.assertEqual(3000, cue.duration)
                 self.assertEqual(1, cue.loop)
+                self.assertIsNone(cue.height)
+                self.assertEqual(480, cue.width)
+
+    def test_fx_video(self):
+        content = textwrap.dedent(
+            """
+            Scene
+            ~~~~~
+
+            Shot
+            ----
+
+            .. fx:: turberfield.dialogue.sequences.battle_royal whack.{0}
+                :offset:    0
+                :duration:  3000
+                :loop:      1
+                :label:     A clip of someone getting whacked
+                :height:    720
+                :poster:    http://soundcloud.com/abcdef/cover.jpg
+                :url:       http://soundcloud.com/abcdef/
+                :width:     1080
+
+            """)
+        for suffix in ("mp4", "ogv", "webm"):
+            with self.subTest(suffix=suffix):
+                text = content.format(suffix)
+                script = SceneScript("inline", doc=SceneScript.read(text))
+                model = script.run()
+                shot, cue = next(iter(model))
+                self.assertIsInstance(cue, Model.Video)
+                self.assertEqual(
+                    "turberfield.dialogue.sequences.battle_royal",
+                    cue.package
+                )
+                self.assertEqual("whack.{0}".format(suffix), cue.resource)
+                self.assertEqual(0, cue.offset)
+                self.assertEqual(3000, cue.duration)
+                self.assertEqual(1, cue.loop)
+                self.assertEqual(720, cue.height)
+                self.assertEqual(1080, cue.width)
 
     def test_fx_unhandled(self):
         content = textwrap.dedent(
